# Generated by Django 4.2.16 on 2024-10-15 06:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_notifications', '0005_debugging'),
    ]

    operations = [
        migrations.AddField(
            model_name='notification',
            name='as_bcc',
            field=models.BooleanField(default=False, help_text='Email message will be sent as BCC values.', verbose_name='As bcc'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='delayed_sending_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Envoi retardé le'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='from_email',
            field=models.EmailField(default='documentation@ville-tourcoing.fr', help_text='Adresse électronique à utiliser comme expéditeur', max_length=254, verbose_name='Expéditeur'),
        ),
        migrations.AlterField(
            model_name='notificationconfig',
            name='debug_notifications_email',
            field=models.EmailField(blank=True, default='', help_text="Adresse électronique d'envoi des copies des notifications.", max_length=254, verbose_name='Adresse électronique de débogage des notifications'),
        ),
        migrations.AlterField(
            model_name='notificationconfig',
            name='delay',
            field=models.PositiveIntegerField(default=0, help_text='Délais en secondes.', verbose_name='Délais'),
        ),
        migrations.AlterField(
            model_name='notificationconfig',
            name='enable_debug_notifications',
            field=models.BooleanField(default=False, help_text="Si activé, une copie des notifications sera envoyé à l'adresse électronique fournie.", verbose_name='Activer les débogage des notifications'),
        ),
    ]
