# Generated by Django 5.2 on 2025-04-11 09:58

import django.db.models.deletion
import django_notifications.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_notifications', '0006_notification_as_bcc_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='attachment',
            name='attachment_file',
            field=models.FileField(upload_to='notifications/attachments/%Y/%m/%d/', verbose_name='Pièce jointe'),
        ),
        migrations.AlterField(
            model_name='attachment',
            name='notification',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='attachments', to='django_notifications.notification', verbose_name='Notification'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='as_bcc',
            field=models.BooleanField(default=False, help_text='Les adresses électronique vont être utilisées dans le champs BCC (copies cachées).', verbose_name='Comme BCC'),
        ),
        migrations.AlterField(
            model_name='notification',
            name='from_email',
            field=models.EmailField(default=django_notifications.models.default_from_email, help_text='Adresse électronique à utiliser comme expéditeur', max_length=254, verbose_name='Expéditeur'),
        ),
    ]
